summaryrefslogtreecommitdiffstats
path: root/content/public/browser/web_contents_delegate.h
diff options
context:
space:
mode:
authormgiuca <mgiuca@chromium.org>2016-01-06 19:18:27 -0800
committerCommit bot <commit-bot@chromium.org>2016-01-07 03:20:04 +0000
commit1c92cab4c88f614b19c4af5fda2cca0f515b6724 (patch)
tree88eb1869d737ced0676558c3a35edc8d6e07486d /content/public/browser/web_contents_delegate.h
parente9533af791d57515fc1d2428321f730de6ae1018 (diff)
downloadchromium_src-1c92cab4c88f614b19c4af5fda2cca0f515b6724.zip
chromium_src-1c92cab4c88f614b19c4af5fda2cca0f515b6724.tar.gz
chromium_src-1c92cab4c88f614b19c4af5fda2cca0f515b6724.tar.bz2
Refactoring WebContentsDelegate::ContentsMouseEvent.
It is now called for all mouse events, not just MOVED and EXITED (matching its name). A new parameter |exited| was added for EXITED events (like the existing |motion| parameter). Rationale: I want to signal the fullscreen bubble on mouse events, and this seemed a good place to do it except it wasn't receiving all mouse events. TBR=wjmaclean@chromium.org Review URL: https://codereview.chromium.org/1566863002 Cr-Commit-Position: refs/heads/master@{#367999}
Diffstat (limited to 'content/public/browser/web_contents_delegate.h')
-rw-r--r--content/public/browser/web_contents_delegate.h8
1 files changed, 5 insertions, 3 deletions
diff --git a/content/public/browser/web_contents_delegate.h b/content/public/browser/web_contents_delegate.h
index 6379fe4..ed46e43 100644
--- a/content/public/browser/web_contents_delegate.h
+++ b/content/public/browser/web_contents_delegate.h
@@ -152,11 +152,13 @@ class CONTENT_EXPORT WebContentsDelegate {
const GURL& url) {}
// Notification that there was a mouse event, along with the absolute
// coordinates of the mouse pointer and whether it was a normal motion event
// (otherwise, the pointer left the contents area).
virtual void ContentsMouseEvent(WebContents* source,
const gfx::Point& location,
- bool motion) {}
+ bool motion,
+ bool exited) {}
// Request the delegate to change the zoom level of the current tab.
virtual void ContentsZoomChange(bool zoom_in) {}
@@ -152,11 +152,13 @@ class CONTENT_EXPORT WebContentsDelegate {
const GURL& url) {}
// Notification that there was a mouse event, along with the absolute
- // coordinates of the mouse pointer and whether it was a normal motion event
- // (otherwise, the pointer left the contents area).
+ // coordinates of the mouse pointer and the type of event. If |motion| is
+ // true, this is a normal motion event. If |exited| is true, the pointer left
+ // the contents area.
virtual void ContentsMouseEvent(WebContents* source,
const gfx::Point& location,